#define OBJECT_1 0;
#define DEVICE_COUNTER_1 2;
#define DEVICE_COUNTER_2 4;
#define DEVICE_COUNTER_3 6;
#define DEVICE_COUNTER_4 8;
#define DEVICE_COUNTER_5 10;
#define DEVICE_COUNTER_6 12;
#define DEVICE_COUNTER_7 14;
#define DEVICE_COUNTER_8 16;
#define DEVICE_COUNTER_9 18;
#define DEVICE_COUNTER_10 20;
#define DEVICE_COUNTER_11 22;
#define DEVICE_COUNTER_12 24;
#define DEVICE_COUNTER_13 26;
#define DEVICE_COUNTER_14 28;

